Documentation
¶
Index ¶
- Constants
- Variables
- func SockaddrToAddr(sa unix.Sockaddr) net.Addr
- func SystemSupportKTLS() (bool, error)
- type Event
- type Fakelock
- type Poll
- func (p *Poll) AddRead(fd int) error
- func (p *Poll) AddReadWrite(fd int) error
- func (p *Poll) Close() error
- func (p *Poll) Del(fd int) error
- func (p *Poll) ModRead(fd int) error
- func (p *Poll) ModReadWrite(fd int) error
- func (p *Poll) Poll(handler func(fd int, event Event))
- func (p *Poll) SetPollWait(msec int)
- func (p *Poll) Trigger(cmd byte) error
- type Spinlock
Constants ¶
const ( PollInitSize = 1024 PollMaxSize = 8192 )
event poll size
const ( CmdStop byte = 0x0 CmdUser byte = 0x1 )
Variables ¶
var ErrKTLSUnsupported = errors.New("ktls unsupported")
Functions ¶
func SockaddrToAddr ¶
SockaddrToAddr returns a go/net friendly address
func SystemSupportKTLS ¶
SystemSupportKTLS reports whether the current system likely supports Linux kTLS. It checks for the tls kernel module and tries enabling the TCP ULP "tls" on a connected socket.
Types ¶
Source Files
¶
Click to show internal directories.
Click to hide internal directories.